==> 0.0.1.tar.gz: feilong-client/Assets/Scripts/Business/Runtime/FGUI/Main/HomePanel/MainHomePanelVM.Gen.cs <==
/// #pkgName FGUI包名
/// #panelName UIPanel名字
/// #UIName = $"{#pkgName}{#panelName}" UIKey名字
/// #PropertyDefineArea 属性定义区域
/// #PropertyAssignArea 属性赋值区域
/// #ComponentType 组件类型
/// #PropertyName 属性名字
/// 该脚本由模板创建，不可编辑
/// created by cb 2024
using FairyGUI;
using XGame.Framework.FGUI;

namespace FL.FGUI
{
    /// <summary>
    /// 该脚本由模板创建，不可修改，不可编辑
    /// </summary>
    public partial class MainHomePanelVM : FguiViewModel
    {
        public Controller C1 { get; private set; }
        public GImage SenLinBottom { get; private set; }
        public GImage TouXiangBottom { get; private set; }
        public GTextField ZLNummber { get; private set; }
        public GTextField ApextTan { get; private set; }
        public GProgressBar LevelpBar { get; private set; }
        public GImage TXKuang { get; private set; }
        public GLoader TouXiang { get; private set; }
        public GImage PlayerLevelBottom { get; private set; }
        public GTextField PlayerLevelNummber { get; private set; }
        public GImage Zhandouli { get; private set; }
        public GImage GoldBottom01 { get; private set; }
        public GTextField GoldNummber { get; private set; }
        public GImage Jinbi { get; private set; }
        public GButton GoldBtn { get; private set; }
        public GImage GoldBottom02 { get; private set; }
        public GTextField DiamindNummber { get; private set; }
        public GButton DiamondBtn { get; private set; }
        public GImage Baoshi { get; private set; }
        public GButton SCBtn { get; private set; }
        public GButton XSLBtn { get; private set; }
        public GButton HDBtn { get; private set; }
        public GButton GoldBox { get; private set; }
        public GButton MailBtn { get; private set; }
        public GButton FriendsBtn { get; private set; }
        public GButton RankBtn { get; private set; }
        public GGroup MailBoxFriends { get; private set; }
        public GImage XinXiLanBottom { get; private set; }
        public GImage TongYongLanBottom { get; private set; }
        public GGroup XinXiLanBto { get; private set; }
        public GImage Roles { get; private set; }
        public GLoader RolesNummber { get; private set; }
        public GLoader LevelNummber { get; private set; }
        public GLoader3D BoxSpine { get; private set; }
        public GButton BoxBtn { get; private set; }
        public GButton RoleBtn { get; private set; }
        public GButton FubenBtn { get; private set; }
        public GButton ShopBtn { get; private set; }
        public GButton HomeBtn { get; private set; }
        public GButton GonghuiBtn { get; private set; }
        public GButton JianlingBtn { get; private set; }
        public GTextField XinWen { get; private set; }
        public GButton TaskBtn { get; private set; }
        public GButton JinJieBtn { get; private set; }
        public GButton AutoBtn { get; private set; }
        public GButton HuanHuaBtn { get; private set; }
        public GImage LanKuang01 { get; private set; }
        public GLoader LoaderWuqi { get; private set; }
        public GImage Eye01 { get; private set; }
        public GTextField Lv01 { get; private set; }
        public GImage HongKuang { get; private set; }
        public GLoader LoaderXiong { get; private set; }
        public GImage Eye02 { get; private set; }
        public GTextField Lv02 { get; private set; }
        public GImage LvKuang { get; private set; }
        public GLoader LoaderTou { get; private set; }
        public GImage Eye03 { get; private set; }
        public GTextField Lv03 { get; private set; }
        public GImage ZiKuang { get; private set; }
        public GLoader LoaderShou { get; private set; }
        public GTextField Lv04 { get; private set; }
        public GImage HuangKuang { get; private set; }
        public GLoader LoaderJiao { get; private set; }
        public GTextField Lv05 { get; private set; }
        public GImage LanKuang02 { get; private set; }
        public GLoader LoaderYao { get; private set; }
        public GTextField Lv06 { get; private set; }
        public GGroup Bottom { get; private set; }
        public Transition T0 { get; private set; }
        public Transition T1 { get; private set; }

        public MainHomePanelVM(GComponent panel) : base(panel)
        {
        }
        protected override void BindComponents(GComponent panel)
        {
            C1 = panel.GetController("c1");
            SenLinBottom = panel.GetChild("SenLinBottom") as GImage;
            TouXiangBottom = panel.GetChild("TouXiangBottom") as GImage;
            ZLNummber = panel.GetChild("ZLNummber") as GTextField;
            ApextTan = panel.GetChild("ApextTan") as GTextField;
            LevelpBar = panel.GetChild("LevelpBar") as GProgressBar;
            TXKuang = panel.GetChild("TXKuang") as GImage;
            TouXiang = panel.GetChild("TouXiang") as GLoader;
            PlayerLevelBottom = panel.GetChild("PlayerLevelBottom") as GImage;
            PlayerLevelNummber = panel.GetChild("PlayerLevelNummber") as GTextField;
            Zhandouli = panel.GetChild("Zhandouli") as GImage;
            GoldBottom01 = panel.GetChild("GoldBottom01") as GImage;
            GoldNummber = panel.GetChild("GoldNummber") as GTextField;
            Jinbi = panel.GetChild("Jinbi") as GImage;
            GoldBtn = panel.GetChild("GoldBtn") as GButton;
            GoldBottom02 = panel.GetChild("GoldBottom02") as GImage;
            DiamindNummber = panel.GetChild("DiamindNummber") as GTextField;
            DiamondBtn = panel.GetChild("DiamondBtn") as GButton;
            Baoshi = panel.GetChild("Baoshi") as GImage;
            SCBtn = panel.GetChild("SCBtn") as GButton;
            XSLBtn = panel.GetChild("XSLBtn") as GButton;
            HDBtn = panel.GetChild("HDBtn") as GButton;
            GoldBox = panel.GetChild("GoldBox") as GButton;
            MailBtn = panel.GetChild("MailBtn") as GButton;
            FriendsBtn = panel.GetChild("FriendsBtn") as GButton;
            RankBtn = panel.GetChild("RankBtn") as GButton;
            MailBoxFriends = panel.GetChild("MailBoxFriends") as GGroup;
            XinXiLanBottom = panel.GetChild("XinXiLanBottom") as GImage;
            TongYongLanBottom = panel.GetChild("TongYongLanBottom") as GImage;
            XinXiLanBto = panel.GetChild("XinXiLanBto") as GGroup;
            Roles = panel.GetChild("Roles") as GImage;
            RolesNummber = panel.GetChild("RolesNummber") as GLoader;
            LevelNummber = panel.GetChild("LevelNummber") as GLoader;
            BoxSpine = panel.GetChild("BoxSpine") as GLoader3D;
            BoxBtn = panel.GetChild("BoxBtn") as GButton;
            RoleBtn = panel.GetChild("RoleBtn") as GButton;
            FubenBtn = panel.GetChild("FubenBtn") as GButton;
            ShopBtn = panel.GetChild("ShopBtn") as GButton;
            HomeBtn = panel.GetChild("HomeBtn") as GButton;
            GonghuiBtn = panel.GetChild("GonghuiBtn") as GButton;
            JianlingBtn = panel.GetChild("JianlingBtn") as GButton;
            XinWen = panel.GetChild("XinWen") as GTextField;
            TaskBtn = panel.GetChild("TaskBtn") as GButton;
            JinJieBtn = panel.GetChild("JinJieBtn") as GButton;
            AutoBtn = panel.GetChild("AutoBtn") as GButton;
            HuanHuaBtn = panel.GetChild("HuanHuaBtn") as GButton;
            LanKuang01 = panel.GetChild("LanKuang01") as GImage;
            LoaderWuqi = panel.GetChild("LoaderWuqi") as GLoader;
            Eye01 = panel.GetChild("Eye01") as GImage;
            Lv01 = panel.GetChild("Lv01") as GTextField;
            HongKuang = panel.GetChild("HongKuang") as GImage;
            LoaderXiong = panel.GetChild("LoaderXiong") as GLoader;
            Eye02 = panel.GetChild("Eye02") as GImage;
            Lv02 = panel.GetChild("Lv02") as GTextField;
            LvKuang = panel.GetChild("LvKuang") as GImage;
            LoaderTou = panel.GetChild("LoaderTou") as GLoader;
            Eye03 = panel.GetChild("Eye03") as GImage;
            Lv03 = panel.GetChild("Lv03") as GTextField;
            ZiKuang = panel.GetChild("ZiKuang") as GImage;
            LoaderShou = panel.GetChild("LoaderShou") as GLoader;
            Lv04 = panel.GetChild("Lv04") as GTextField;
            HuangKuang = panel.GetChild("HuangKuang") as GImage;
            LoaderJiao = panel.GetChild("LoaderJiao") as GLoader;
            Lv05 = panel.GetChild("Lv05") as GTextField;
            LanKuang02 = panel.GetChild("LanKuang02") as GImage;
            LoaderYao = panel.GetChild("LoaderYao") as GLoader;
            Lv06 = panel.GetChild("Lv06") as GTextField;
            Bottom = panel.GetChild("Bottom") as GGroup;
            T0 = panel.GetTransition("t0");
            T1 = panel.GetTransition("t1");

        }
    }
}

==> 0.0.2.tar.gz: feilong-client/Assets/Scripts/Business/Runtime/FGUI/Main/HomePanel/MainHomePanelVM.Gen.cs <==
/// #pkgName FGUI包名
/// #panelName UIPanel名字
/// #UIName = $"{#pkgName}{#panelName}" UIKey名字
/// #PropertyDefineArea 属性定义区域
/// #PropertyAssignArea 属性赋值区域
/// #ComponentType 组件类型
/// #PropertyName 属性名字
/// 该脚本由模板创建，不可编辑
/// created by cb 2024
using FairyGUI;
using XGame.Framework.FGUI;
using XGame.Framework.UI;

namespace FL.FGUI
{
    /// <summary>
    /// 该脚本由模板创建，不可修改，不可编辑
    /// </summary>
    public partial class MainHomePanelVM : FguiViewModel
    {
        public Controller C1 { get; private set; }
        public GImage SenLinBottom { get; private set; }
        public GImage TouXiangBottom { get; private set; }
        public GTextField ZLNummber { get; private set; }
        public GTextField ApextTan { get; private set; }
        public GProgressBar LevelpBar { get; private set; }
        public GImage TXKuang { get; private set; }
        public GLoader TouXiang { get; private set; }
        public GImage PlayerLevelBottom { get; private set; }
        public GTextField PlayerLevelNummber { get; private set; }
        public GImage Zhandouli { get; private set; }
        public GImage GoldBottom01 { get; private set; }
        public GTextField GoldNummber { get; private set; }
        public GImage Jinbi { get; private set; }
        public GButton GoldBtn { get; private set; }
        public GImage GoldBottom02 { get; private set; }
        public GTextField DiamindNummber { get; private set; }
        public GButton DiamondBtn { get; private set; }
        public GImage Baoshi { get; private set; }
        public GButton SCBtn { get; private set; }
        public GButton XSLBtn { get; private set; }
        public GButton HDBtn { get; private set; }
        public GButton GoldBox { get; private set; }
        public GButton MailBtn { get; private set; }
        public GButton FriendsBtn { get; private set; }
        public GButton RankBtn { get; private set; }
        public GGroup MailBoxFriends { get; private set; }
        public GImage XinXiLanBottom { get; private set; }
        public GImage TongYongLanBottom { get; private set; }
        public GGroup XinXiLanBto { get; private set; }
        public GImage Roles { get; private set; }
        public GLoader RolesNummber { get; private set; }
        public GLoader LevelNummber { get; private set; }
        public GLoader3D BoxSpine { get; private set; }
        public GButton BoxBtn { get; private set; }
        public GButton RoleBtn { get; private set; }
        public GButton FubenBtn { get; private set; }
        public GButton ShopBtn { get; private set; }
        public GButton HomeBtn { get; private set; }
        public GButton GonghuiBtn { get; private set; }
        public GButton JianlingBtn { get; private set; }
        public GTextField XinWen { get; private set; }
        public GButton TaskBtn { get; private set; }
        public GButton JinJieBtn { get; private set; }
        public GButton AutoBtn { get; private set; }
        public GButton HuanHuaBtn { get; private set; }
        public GImage LanKuang01 { get; private set; }
        public GLoader LoaderWuqi { get; private set; }
        public GImage Eye01 { get; private set; }
        public GTextField Lv01 { get; private set; }
        public GImage HongKuang { get; private set; }
        public GLoader LoaderXiong { get; private set; }
        public GImage Eye02 { get; private set; }
        public GTextField Lv02 { get; private set; }
        public GImage LvKuang { get; private set; }
        public GLoader LoaderTou { get; private set; }
        public GImage Eye03 { get; private set; }
        public GTextField Lv03 { get; private set; }
        public GImage ZiKuang { get; private set; }
        public GLoader LoaderShou { get; private set; }
        public GTextField Lv04 { get; private set; }
        public GImage HuangKuang { get; private set; }
        public GLoader LoaderJiao { get; private set; }
        public GTextField Lv05 { get; private set; }
        public GImage LanKuang02 { get; private set; }
        public GLoader LoaderYao { get; private set; }
        public GTextField Lv06 { get; private set; }
        public GGroup Bottom { get; private set; }
        public MainListShopView ListShop { get; private set; }
        public Transition T0 { get; private set; }
        public Transition T1 { get; private set; }

        protected override void BindComponents(GComponent panel, IUIViewAdapter adapter)
        {
            C1 = panel.GetController("c1");
            SenLinBottom = panel.GetChild("SenLinBottom") as GImage;
            TouXiangBottom = panel.GetChild("TouXiangBottom") as GImage;
            ZLNummber = panel.GetChild("ZLNummber") as GTextField;
            ApextTan = panel.GetChild("ApextTan") as GTextField;
            LevelpBar = panel.GetChild("LevelpBar") as GProgressBar;
            TXKuang = panel.GetChild("TXKuang") as GImage;
            TouXiang = panel.GetChild("TouXiang") as GLoader;
            PlayerLevelBottom = panel.GetChild("PlayerLevelBottom") as GImage;
            PlayerLevelNummber = panel.GetChild("PlayerLevelNummber") as GTextField;
            Zhandouli = panel.GetChild("Zhandouli") as GImage;
            GoldBottom01 = panel.GetChild("GoldBottom01") as GImage;
            GoldNummber = panel.GetChild("GoldNummber") as GTextField;
            Jinbi = panel.GetChild("Jinbi") as GImage;
            GoldBtn = panel.GetChild("GoldBtn") as GButton;
            GoldBottom02 = panel.GetChild("GoldBottom02") as GImage;
            DiamindNummber = panel.GetChild("DiamindNummber") as GTextField;
            DiamondBtn = panel.GetChild("DiamondBtn") as GButton;
            Baoshi = panel.GetChild("Baoshi") as GImage;
            SCBtn = panel.GetChild("SCBtn") as GButton;
            XSLBtn = panel.GetChild("XSLBtn") as GButton;
            HDBtn = panel.GetChild("HDBtn") as GButton;
            GoldBox = panel.GetChild("GoldBox") as GButton;
            MailBtn = panel.GetChild("MailBtn") as GButton;
            FriendsBtn = panel.GetChild("FriendsBtn") as GButton;
            RankBtn = panel.GetChild("RankBtn") as GButton;
            MailBoxFriends = panel.GetChild("MailBoxFriends") as GGroup;
            XinXiLanBottom = panel.GetChild("XinXiLanBottom") as GImage;
            TongYongLanBottom = panel.GetChild("TongYongLanBottom") as GImage;
            XinXiLanBto = panel.GetChild("XinXiLanBto") as GGroup;
            Roles = panel.GetChild("Roles") as GImage;
            RolesNummber = panel.GetChild("RolesNummber") as GLoader;
            LevelNummber = panel.GetChild("LevelNummber") as GLoader;
            BoxSpine = panel.GetChild("BoxSpine") as GLoader3D;
            BoxBtn = panel.GetChild("BoxBtn") as GButton;
            RoleBtn = panel.GetChild("RoleBtn") as GButton;
            FubenBtn = panel.GetChild("FubenBtn") as GButton;
            ShopBtn = panel.GetChild("ShopBtn") as GButton;
            HomeBtn = panel.GetChild("HomeBtn") as GButton;
            GonghuiBtn = panel.GetChild("GonghuiBtn") as GButton;
            JianlingBtn = panel.GetChild("JianlingBtn") as GButton;
            XinWen = panel.GetChild("XinWen") as GTextField;
            TaskBtn = panel.GetChild("TaskBtn") as GButton;
            JinJieBtn = panel.GetChild("JinJieBtn") as GButton;
            AutoBtn = panel.GetChild("AutoBtn") as GButton;
            HuanHuaBtn = panel.GetChild("HuanHuaBtn") as GButton;
            LanKuang01 = panel.GetChild("LanKuang01") as GImage;
            LoaderWuqi = panel.GetChild("LoaderWuqi") as GLoader;
            Eye01 = panel.GetChild("Eye01") as GImage;
            Lv01 = panel.GetChild("Lv01") as GTextField;
            HongKuang = panel.GetChild("HongKuang") as GImage;
            LoaderXiong = panel.GetChild("LoaderXiong") as GLoader;
            Eye02 = panel.GetChild("Eye02") as GImage;
            Lv02 = panel.GetChild("Lv02") as GTextField;
            LvKuang = panel.GetChild("LvKuang") as GImage;
            LoaderTou = panel.GetChild("LoaderTou") as GLoader;
            Eye03 = panel.GetChild("Eye03") as GImage;
            Lv03 = panel.GetChild("Lv03") as GTextField;
            ZiKuang = panel.GetChild("ZiKuang") as GImage;
            LoaderShou = panel.GetChild("LoaderShou") as GLoader;
            Lv04 = panel.GetChild("Lv04") as GTextField;
            HuangKuang = panel.GetChild("HuangKuang") as GImage;
            LoaderJiao = panel.GetChild("LoaderJiao") as GLoader;
            Lv05 = panel.GetChild("Lv05") as GTextField;
            LanKuang02 = panel.GetChild("LanKuang02") as GImage;
            LoaderYao = panel.GetChild("LoaderYao") as GLoader;
            Lv06 = panel.GetChild("Lv06") as GTextField;
            Bottom = panel.GetChild("Bottom") as GGroup;
            ListShop = adapter.CreateNested<MainListShopView>(new FguiNested(panel.GetChild("listShop").asCom), true);
            T0 = panel.GetTransition("t0");
            T1 = panel.GetTransition("t1");

        }
    }
}
